==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/event/observer/resolve/BullTerrier.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.event.observer.resolve;

import javax.enterprise.event.Observes;

public class BullTerrier {
    private static boolean multiBindingEventObserved = false;
    private static boolean singleBindingEventObserved = false;

    public void observesMultiBindingEvent(@Observes @Role("Admin") @Tame MultiBindingEvent someEvent) {
        multiBindingEventObserved = true;
    }

    public void observesSingleBindingEvent(@Observes @Tame MultiBindingEvent someEvent) {
        singleBindingEventObserved = true;
    }

    public static boolean isMultiBindingEventObserved() {
        return multiBindingEventObserved;
    }

    public static boolean isSingleBindingEventObserved() {
        return singleBindingEventObserved;
    }

    public static void reset() {
        multiBindingEventObserved = false;
        singleBindingEventObserved = false;
    }
}

==> cdi-tck-3.0.2-dist.zip: org/jboss/cdi/tck/tests/event/observer/resolve/BullTerrier.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.event.observer.resolve;

import jakarta.enterprise.event.Observes;

public class BullTerrier {
    private static boolean multiBindingEventObserved = false;
    private static boolean singleBindingEventObserved = false;

    public void observesMultiBindingEvent(@Observes @Role("Admin") @Tame MultiBindingEvent someEvent) {
        multiBindingEventObserved = true;
    }

    public void observesSingleBindingEvent(@Observes @Tame MultiBindingEvent someEvent) {
        singleBindingEventObserved = true;
    }

    public static boolean isMultiBindingEventObserved() {
        return multiBindingEventObserved;
    }

    public static boolean isSingleBindingEventObserved() {
        return singleBindingEventObserved;
    }

    public static void reset() {
        multiBindingEventObserved = false;
        singleBindingEventObserved = false;
    }
}
